@@ -44,8 +44,8 @@ from kazoo.exceptions import (
     ZookeeperError,
 )
 from kazoo.handlers.threading import TimeoutError
+from kazoo.security import OPEN_ACL_UNSAFE, READ_ACL_UNSAFE
 
-from . import __version__
 from .acl import ACLReader
 from .augumented_client import AugumentedClient
 from .augumented_cmd import (
@@ -72,7 +72,6 @@ class Shell(AugumentedCmd):
         self._zk = None
         self._read_only = False
         self.connected = False
-        self.intro = "Welcome to zk-shell (%s)" % (__version__)
 
         if len(self._hosts) > 0: self._connect(self._hosts)
         if not self.connected: self.update_curdir("/")
@@ -145,16 +144,37 @@ class Shell(AugumentedCmd):
         return self._complete_path(cmd_param_text, full_cmd)
 
     @connected
-    @ensure_params(Required("path"))
+    @interruptible
+    @ensure_params(Required("path"), IntegerOptional("depth", -1), BooleanOptional("ephemerals"))
     @check_path_exists
     def do_get_acls(self, params):
         """
         gets ACLs for a given path.
-        example:
+
+        get_acls <path> [depth] [ephemerals]
+
+        by the default this won't recurse. 0 means infinite recursion.
+
+        examples:
         get_acls /zookeeper
         [ACL(perms=31, acl_list=['ALL'], id=Id(scheme=u'world', id=u'anyone'))]
+
+        get_acls /zookeeper -1
+        /zookeeper: [ACL(perms=31, acl_list=['ALL'], id=Id(scheme=u'world', id=u'anyone'))]
+        /zookeeper/config: [ACL(perms=31, acl_list=['ALL'], id=Id(scheme=u'world', id=u'anyone'))]
+        /zookeeper/quota: [ACL(perms=31, acl_list=['ALL'], id=Id(scheme=u'world', id=u'anyone'))]
         """
-        print(self._zk.get_acls(params.path)[0], file=self._output)
+        def replace(l, oldv, newv):
+            try:
+                l.remove(oldv)
+                l.insert(0, newv)
+            except ValueError:
+                pass
+
+        for p, acls in self._zk.get_acls_recursive(params.path, params.depth, params.ephemerals):
+            replace(acls, READ_ACL_UNSAFE[0], "WORLD_READ")
+            replace(acls, OPEN_ACL_UNSAFE[0], "WORLD_ALL")
+            print("%s: %s" % (p, acls), file=self._output)
 
     def complete_get_acls(self, cmd_param_text, full_cmd, start_idx, end_idx):
         return self._complete_path(cmd_param_text, full_cmd)
@@ -283,9 +303,8 @@ class Shell(AugumentedCmd):
         ├── bar
         """
         print(".", file=self._output)
-        def print_node(c, l):
+        for c, l in self._zk.tree(params.path, params.max_depth):
             print(u"%s├── %s" % (u"│   " * l, c), file=self._output)
-        self._zk.tree(params.path, params.max_depth, print_node)
 
     def complete_tree(self, cmd_param_text, full_cmd, start_idx, end_idx):
         return self._complete_path(cmd_param_text, full_cmd)
